@@ -22,16 +22,13 @@
 #ifndef EVENTVIEWS_TIMELABELSZONE_H
 #define EVENTVIEWS_TIMELABELSZONE_H
 
-
 #include <QWidget>
 
 class QHBoxLayout;
 class QScrollArea;
 class QTimeZone;
 
-namespace EventViews
-{
-
+namespace EventViews {
 class Agenda;
 class AgendaView;
 
@@ -52,17 +49,17 @@ public:
     /**
        Returns the best width for each TimeLabels widget
     */
-    int preferedTimeLabelsWidth() const;
+    Q_REQUIRED_RESULT int preferedTimeLabelsWidth() const;
 
     void updateAll();
     void reset();
     void init();
     void setAgendaView(AgendaView *agenda);
 
-    QList<QScrollArea *> timeLabels() const;
+    Q_REQUIRED_RESULT QList<QScrollArea *> timeLabels() const;
 
     void setPreferences(const PrefsPtr &prefs);
-    PrefsPtr preferences() const;
+    Q_REQUIRED_RESULT PrefsPtr preferences() const;
 
     /** Checks how much agenda is scrolled relative to it's QScrollArea
         and makes each TimeLabels scroll that amount
@@ -71,14 +68,13 @@ public:
 
 private:
     void setupTimeLabel(QScrollArea *area);
-    Agenda *mAgenda;
+    Agenda *mAgenda = nullptr;
     PrefsPtr mPrefs;
-    AgendaView *mParent;
+    AgendaView *mParent = nullptr;
 
-    QHBoxLayout *mTimeLabelsLayout;
+    QHBoxLayout *mTimeLabelsLayout = nullptr;
     QList<QScrollArea *> mTimeLabelsList;
 };
-
 }
 
 #endif
