@@ -114,7 +114,7 @@ void EventView::setHolidayRegions(const QStringList &regions)
     Q_D(EventView);
     qDeleteAll(d->mHolidayRegions);
     d->mHolidayRegions.clear();
-    foreach (const QString &regionStr, regions) {
+    for (const QString &regionStr : regions) {
         KHolidays::HolidayRegion *region = new KHolidays::HolidayRegion(regionStr);
         if (region->isValid()) {
             d->mHolidayRegions.append(region);
@@ -627,14 +627,14 @@ bool EventView::makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) con
 
     // Last check: must be organizer or attendee:
 
-    if (kcalPreferences()->thatIsMe(ev->organizer()->email())) {
+    if (kcalPreferences()->thatIsMe(ev->organizer().email())) {
         return true;
     }
 
     KCalCore::Attendee::List attendees = ev->attendees();
     KCalCore::Attendee::List::ConstIterator it;
     for (it = attendees.constBegin(); it != attendees.constEnd(); ++it) {
-        if (kcalPreferences()->thatIsMe((*it)->email())) {
+        if (kcalPreferences()->thatIsMe((*it).email())) {
             return true;
         }
     }
