@@ -40,11 +40,6 @@
 #include <QByteArray>
 #include <QDate>
 
-namespace KCalCore {
-template<typename T> class SortableList;
-typedef SortableList<QDate> DateList;
-}
-
 namespace CalendarSupport {
 class CollectionSelection;
 class KCalPrefs;
@@ -86,7 +81,7 @@ class EVENTVIEWS_EXPORT EventView : public QWidget
 public:
     enum {
         // This value is passed to QColor's lighter(int factor) for selected events
-        BRIGHTNESS_FACTOR = 125
+        BRIGHTNESS_FACTOR = 110
     };
 
     enum ItemIcon {
