@@ -37,7 +37,6 @@
 #include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
-#include <CalendarSupport/KCalPrefs>
 #include <Akonadi/Calendar/IncidenceChanger>
 
 #include "calendarview_debug.h"
@@ -56,8 +55,7 @@
 using namespace KCalCore;
 using namespace EventViews;
 
-namespace EventViews
-{
+namespace EventViews {
 class RowController : public KGantt::AbstractRowController
 {
 private:
@@ -151,12 +149,10 @@ public:
 };
 class GanttItemDelegate : public KGantt::ItemDelegate
 {
-    void paintGanttItem(QPainter *painter,
-                        const KGantt::StyleOptionGanttItem &opt,
-                        const QModelIndex &idx) override {
+    void paintGanttItem(QPainter *painter, const KGantt::StyleOptionGanttItem &opt, const QModelIndex &idx) override
+    {
         painter->setRenderHints(QPainter::Antialiasing);
-        if (!idx.isValid())
-        {
+        if (!idx.isValid()) {
             return;
         }
         KGantt::ItemType type = static_cast<KGantt::ItemType>(
@@ -169,10 +165,9 @@ class GanttItemDelegate : public KGantt::ItemDelegate
         boundingRect.setHeight(itemRect.height());
 
         QBrush brush = defaultBrush(type);
-        if (opt.state & QStyle::State_Selected)
-        {
+        if (opt.state & QStyle::State_Selected) {
             QLinearGradient selectedGrad(0., 0., 0.,
-            QApplication::fontMetrics().height());
+                                         QApplication::fontMetrics().height());
             selectedGrad.setColorAt(0., Qt::red);
             selectedGrad.setColorAt(1., Qt::darkRed);
 
@@ -185,8 +180,7 @@ class GanttItemDelegate : public KGantt::ItemDelegate
         painter->setPen(defaultPen(type));
         painter->setBrushOrigin(itemRect.topLeft());
 
-        switch (type)
-        {
+        switch (type) {
         case KGantt::TypeTask:
             if (itemRect.isValid()) {
                 QRectF r = itemRect;
@@ -218,11 +212,11 @@ class GanttItemDelegate : public KGantt::ItemDelegate
         }
     }
 };
-
 }
 
 TimelineView::TimelineView(QWidget *parent)
-    : EventView(parent), d(new Private(this))
+    : EventView(parent)
+    , d(new Private(this))
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
     QSplitter *splitter = new QSplitter(Qt::Horizontal, this);
@@ -231,6 +225,7 @@ TimelineView::TimelineView(QWidget *parent)
     d->mLeftView->setHeaderLabel(i18n("Calendar"));
     d->mLeftView->setRootIsDecorated(false);
     d->mLeftView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    d->mLeftView->setUniformRowHeights(true);
 
     d->mGantt = new KGantt::GraphicsView();
     splitter->addWidget(d->mLeftView);
@@ -240,7 +235,12 @@ TimelineView::TimelineView(QWidget *parent)
     QStandardItemModel *model = new QStandardItemModel(this);
 
     d->mRowController = new RowController;
-    d->mRowController->setRowHeight(fontMetrics().height());   //TODO: detect
+
+    QStyleOptionViewItem opt;
+    opt.initFrom(d->mLeftView);
+    const auto h = d->mLeftView->style()->sizeFromContents(QStyle::CT_ItemViewItem, &opt,
+                                                           QSize(), d->mLeftView).height();
+    d->mRowController->setRowHeight(h);
 
     d->mRowController->setModel(model);
     d->mGantt->setRowController(d->mRowController);
@@ -253,50 +253,18 @@ TimelineView::TimelineView(QWidget *parent)
     d->mGantt->viewport()->setFixedWidth(8000);
 
     d->mGantt->viewport()->installEventFilter(this);
-
-#if 0
-    d->mGantt->setCalendarMode(true);
-    d->mGantt->setShowLegendButton(false);
-    d->mGantt->setFixedHorizon(true);
-    d->mGantt->removeColumn(0);
-    d->mGantt->addColumn(i18n("Calendar"));
-    d->mGantt->setHeaderVisible(true);
-    if (KLocale::global()->use12Clock()) {
-        d->mGantt->setHourFormat(KDGanttView::Hour_12);
-    } else {
-        d->mGantt->setHourFormat(KDGanttView::Hour_24_FourDigit);
-    }
-#else
-    qCDebug(CALENDARVIEW_LOG) << "Disabled code, port to KDGantt2";
-#endif
     d->mGantt->setItemDelegate(new GanttItemDelegate);
 
     vbox->addWidget(splitter);
 
-#if 0
-    connect(d->mGantt, SIGNAL(rescaling(KDGanttView::Scale)),
-            SLOT(overscale(KDGanttView::Scale)));
-#else
-    qCDebug(CALENDARVIEW_LOG) << "Disabled code, port to KDGantt2";
-#endif
     connect(model, &QStandardItemModel::itemChanged,
             d, &Private::itemChanged);
 
-    //TODO FIXME doubleClicked doesn't exist PORTING KDIAGRAM
-    //connect(d->mGantt, &KGantt::GraphicsView::doubleClicked,
-    //        d, &Private::itemDoubleClicked);
     connect(d->mGantt, &KGantt::GraphicsView::activated,
             d, &Private::itemSelected);
     d->mGantt->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(d->mGantt, &QWidget::customContextMenuRequested,
             d, &Private::contextMenuRequested);
-
-#if 0
-    connect(d->mGantt, SIGNAL(dateTimeDoubleClicked(QDateTime)),
-            d, SLOT(newEventWithHint(QDateTime)));
-#else
-    qCDebug(CALENDARVIEW_LOG) << "Disabled code, port to KDGantt2";
-#endif
 }
 
 TimelineView::~TimelineView()
@@ -335,21 +303,6 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
 
     KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
     grid->setStartDateTime(QDateTime(start));
-#if 0
-    d->mGantt->setHorizonStart(QDateTime(start));
-    d->mGantt->setHorizonEnd(QDateTime(end.addDays(1)));
-    d->mGantt->setMinorScaleCount(1);
-    d->mGantt->setScale(KDGanttView::Hour);
-    d->mGantt->setMinimumScale(KDGanttView::Hour);
-    d->mGantt->setMaximumScale(KDGanttView::Hour);
-    d->mGantt->zoomToFit();
-
-    d->mGantt->setUpdateEnabled(false);
-    d->mGantt->clear();
-#else
-    qCDebug(CALENDARVIEW_LOG) << "Disabled code, port to KDGantt2";
-#endif
-
     d->mLeftView->clear();
     uint index = 0;
     // item for every calendar
@@ -362,7 +315,6 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
                                 d->mGantt);
         d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << i18n("Calendar")));
         d->mCalendarItemMap.insert(-1, item);
-
     } else {
         const CalendarSupport::CollectionSelection *colSel = collectionSelection();
         const Akonadi::Collection::List collections = colSel->selectedCollections();
@@ -375,14 +327,17 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
                                         d->mGantt);
                 d->mLeftView->addTopLevelItem(
                     new QTreeWidgetItem(
-                        QStringList() << CalendarSupport::displayName(calendar().data(), collection)));
+                        QStringList() << CalendarSupport::displayName(
+                            calendar().data(), collection)));
                 const QColor resourceColor = EventViews::resourceColor(collection, preferences());
                 if (resourceColor.isValid()) {
                     item->setColor(resourceColor);
                 }
                 qCDebug(CALENDARVIEW_LOG) << "Created item " << item
-                                          << " (" <<  CalendarSupport::displayName(calendar().data(), collection) << ") "
-                                          << "with index " <<  index - 1 << " from collection " << collection.id();
+                                          << " (" <<  CalendarSupport::displayName(
+                    calendar().data(), collection) << ") "
+                                          << "with index " <<  index - 1 << " from collection "
+                                          << collection.id();
                 d->mCalendarItemMap.insert(collection.id(), item);
             }
         }
@@ -399,12 +354,11 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mGantt->setModel(nullptr);
 
     KCalCore::Event::List events;
-    KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
     for (QDate day = start; day <= end; day = day.addDays(1)) {
-        events = calendar()->events(day, timeSpec,
+        events = calendar()->events(day, QTimeZone::systemTimeZone(),
                                     KCalCore::EventSortStartDate,
                                     KCalCore::SortDirectionAscending);
-        Q_FOREACH (const KCalCore::Event::Ptr &event, events) {
+        for (const KCalCore::Event::Ptr &event : qAsConst(events)) {
             if (event->hasRecurrenceId()) {
                 continue;
             }
@@ -447,8 +401,7 @@ void TimelineView::changeIncidenceDisplay(const Akonadi::Item &incidence, int mo
     }
 }
 
-bool TimelineView::eventDurationHint(QDateTime &startDt, QDateTime &endDt,
-                                     bool &allDay) const
+bool TimelineView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const
 {
     startDt = QDateTime(d->mHintDate);
     endDt = QDateTime(d->mHintDate.addSecs(2 * 60 * 60));
@@ -456,20 +409,6 @@ bool TimelineView::eventDurationHint(QDateTime &startDt, QDateTime &endDt,
     return d->mHintDate.isValid();
 }
 
-// void TimelineView::overscale( KDGanttView::Scale scale )
-// {
-//   Q_UNUSED( scale );
-//   /* Disabled, looks *really* bogus:
-//      this triggers and endless rescaling loop; we want to set
-//      a fixed scale, the Gantt view doesn't like it and rescales
-//      (emitting a rescaling signal that leads here) and so on...
-//   //set a relative zoom factor of 1 (?!)
-//   d->mGantt->setZoomFactor( 1, false );
-//   d->mGantt->setScale( KDGanttView::Hour );
-//   d->mGantt->setMinorScaleCount( 12 );
-//   */
-// }
-
 QDate TimelineView::startDate() const
 {
     return d->mStartDate;
@@ -490,11 +429,12 @@ bool TimelineView::eventFilter(QObject *object, QEvent *event)
                 KGantt::GraphicsItem *graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
                 const QModelIndex itemIndex = graphicsItem->index();
 
-                QStandardItemModel *itemModel =
-                    qobject_cast<QStandardItemModel *>(d->mGantt->model());
+                QStandardItemModel *itemModel
+                    = qobject_cast<QStandardItemModel *>(d->mGantt->model());
 
-                TimelineSubItem *timelineItem =
-                    dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(), itemIndex.column()));
+                TimelineSubItem *timelineItem
+                    = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(),
+                                                                      itemIndex.column()));
 
                 if (timelineItem) {
                     timelineItem->updateToolTip();
@@ -505,4 +445,3 @@ bool TimelineView::eventFilter(QObject *object, QEvent *event)
 
     return EventView::eventFilter(object, event);
 }
-
