@@ -32,7 +32,7 @@ static void calculateDepth(const Node::Ptr &node)
 {
     Q_ASSERT(node);
     node->depth = node->parentNode ? 1 + node->parentNode->depth : 0;
-    foreach (const Node::Ptr &child, node->directChilds) {
+    for (const Node::Ptr &child : qAsConst(node->directChilds)) {
         calculateDepth(child);
     }
 }
@@ -59,8 +59,8 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
     PreNode::List remainingNodes = nodes;
 
     while (prenodeByUid.count() < count) {
-        bool foundAtLeastOne = false; // this bool saves us from infinit looping if the parent doesn't exist
-        foreach (const PreNode::Ptr &node, remainingNodes) {
+        const auto preSize = prenodeByUid.count(); // this saves us from infinit looping if the parent doesn't exist
+        for (const PreNode::Ptr &node : nodes) {
             Q_ASSERT(node);
             const QString uid = node->incidence->instanceIdentifier();
             const QString parentUid = node->incidence->relatedTo();
@@ -68,18 +68,16 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
                 prenodeByUid.insert(uid, node);
                 remainingNodes.removeAll(node);
                 node->depth = 0;
-                foundAtLeastOne = true;
             } else {
                 if (prenodeByUid.contains(parentUid)) {
                     node->depth = 1 + prenodeByUid.value(parentUid)->depth;
                     remainingNodes.removeAll(node);
                     prenodeByUid.insert(uid, node);
-                    foundAtLeastOne = true;
                 }
             }
         }
 
-        if (!foundAtLeastOne) {
+        if (preSize == prenodeByUid.count()) {
             break;
         }
     }
@@ -321,9 +319,9 @@ void IncidenceTreeModel::Private::onRowsInserted(const QModelIndex &parent, int
         nodes << node;
     }
 
-    PreNode::List sortedNodes = sortedPrenodes(nodes);
+    const PreNode::List sortedNodes = sortedPrenodes(nodes);
 
-    foreach (const PreNode::Ptr &node, sortedNodes) {
+    for (const PreNode::Ptr &node : sortedNodes) {
         insertNode(node);
     }
 
@@ -411,7 +409,7 @@ void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool s
         m_waitingForParent.remove(node->uid);
         Q_ASSERT(!childs.isEmpty());
 
-        foreach (const Node::Ptr &child, childs) {
+        for (const Node::Ptr &child : childs) {
             const int fromRow = m_toplevelNodeList.indexOf(child);
             Q_ASSERT(fromRow != -1);
             const QModelIndex toParent = indexForNode(node);
@@ -447,7 +445,7 @@ Node::List IncidenceTreeModel::Private::sorted(const Node::List &nodes) const
     }
 
     // Initialize depths
-    foreach (const Node::Ptr &topLevelNode, m_toplevelNodeList) {
+    for (const Node::Ptr &topLevelNode : qAsConst(m_toplevelNodeList)) {
         calculateDepth(topLevelNode);
     }
 
@@ -485,9 +483,9 @@ void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &pare
     }
 
     // We want to remove childs first, to avoid row moving
-    Node::List nodesToRemoveSorted = sorted(nodesToRemove);
+    const Node::List nodesToRemoveSorted = sorted(nodesToRemove);
 
-    foreach (const Node::Ptr &node, nodesToRemoveSorted) {
+    for (const Node::Ptr &node : nodesToRemoveSorted) {
         // Go ahead and remove it now. We don't do it in ::onRowsRemoved(), because
         // while unparenting childs with moveRows() the view might call data() on the
         // item that is already removed from ETM.
@@ -508,7 +506,7 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
 
     // First, unparent the children
     if (!node->directChilds.isEmpty()) {
-        Node::List childs = node->directChilds;
+        const Node::List childs = node->directChilds;
         const QModelIndex fromParent = indexForNode(node);
         Q_ASSERT(fromParent.isValid());
 //    const int firstSourceRow = 0;
@@ -518,7 +516,7 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
         //                  /**toParent is root*/QModelIndex(), toRow );
         q->beginResetModel();
         node->directChilds.clear();
-        foreach (const Node::Ptr &child, childs) {
+        for (const Node::Ptr &child : childs) {
             //qCDebug(CALENDARVIEW_LOG) << "Dealing with child: " << child.data() << child->uid;
             m_toplevelNodeList.append(child);
             child->parentNode = Node::Ptr();
@@ -916,7 +914,7 @@ QDebug operator<<(QDebug s, const Node::Ptr &node)
       << QStringLiteral(";id=") << node->id << QStringLiteral(";parentUid=") << node->parentUid
       << QStringLiteral(";parentNode=") << (void *)(node->parentNode.data()) << '\n';
 
-    foreach (const Node::Ptr &child, node->directChilds) {
+    for (const Node::Ptr &child : qAsConst(node->directChilds)) {
         s << child;
     }
 
