@@ -181,8 +181,8 @@ void TodoModel::Private::onLayoutAboutToBeChanged()
     Q_ASSERT(m_persistentIndexes.isEmpty());
     Q_ASSERT(m_layoutChangePersistentIndexes.isEmpty());
     Q_ASSERT(m_columns.isEmpty());
-    QModelIndexList persistentIndexes = q->persistentIndexList();
-    foreach (const QPersistentModelIndex &persistentIndex, persistentIndexes) {
+    const QModelIndexList persistentIndexes = q->persistentIndexList();
+    for (const QPersistentModelIndex &persistentIndex : persistentIndexes) {
         m_persistentIndexes << persistentIndex; // Stuff we have to update onLayoutChanged
         Q_ASSERT(persistentIndex.isValid());
         QModelIndex index_col0 = q->createIndex(persistentIndex.row(), 0,
@@ -771,8 +771,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                 KCalCore::Todo::Ptr oldTodo = KCalCore::Todo::Ptr(destTodo->clone());
 
                 if (text.startsWith(QLatin1String("file:"))) {
-                    destTodo->addAttachment(KCalCore::Attachment::Ptr(new KCalCore::Attachment(
-                                                                          text)));
+                    destTodo->addAttachment(KCalCore::Attachment(text));
                 } else {
                     QStringList emails = KEmailAddress::splitAddressList(text);
                     for (QStringList::ConstIterator it = emails.constBegin();
@@ -780,8 +779,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                         QString name, email, comment;
                         if (KEmailAddress::splitAddress(*it, name, email, comment)
                             == KEmailAddress::AddressOk) {
-                            destTodo->addAttendee(
-                                KCalCore::Attendee::Ptr(new KCalCore::Attendee(name, email)));
+                            destTodo->addAttendee(KCalCore::Attendee(name, email));
                         }
                     }
                 }
