@@ -98,7 +98,7 @@ public:
     {
         const QString todoMimeType = QStringLiteral("application/x-vnd.akonadi.calendar.todo");
         if (flat) {
-            foreach (TodoView *view, views) {
+            for (TodoView *view : qAsConst(views)) {
                 // In flatview dropping confuses users and it's very easy to drop into a child item
                 view->mView->setDragDropMode(QAbstractItemView::DragOnly);
                 view->setFlatView(flat, /**propagate=*/ false);   // So other views update their toggle icon
@@ -119,7 +119,7 @@ public:
         } else {
             delete todoTreeModel;
             todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, parent);
-            foreach (TodoView *view, views) {
+            for (TodoView *view : qAsConst(views)) {
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view,
                                  &TodoView::expandIndex);
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view,
@@ -133,7 +133,7 @@ public:
             todoFlatModel = nullptr;
         }
 
-        foreach (TodoView *view, views) {
+        for (TodoView *view : qAsConst(views)) {
             view->mFlatViewButton->blockSignals(true);
             // We block signals to avoid recursion, we have two TodoViews and mFlatViewButton is synchronized
             view->mFlatViewButton->setChecked(flat);
@@ -328,7 +328,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
         i18nc("@action:inmenu show the to-do", "&Show"),
-        this, SLOT(showTodo()));
+        this, &TodoView::showTodo);
 
     QAction *a = mItemPopupMenu->addAction(
         i18nc("@action:inmenu edit the to-do", "&Edit..."),
@@ -345,13 +345,13 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
         QIcon::fromTheme(QStringLiteral("document-print-preview")),
         i18nc("@action:inmenu print preview the to-do", "Print Previe&w..."),
-        this, SIGNAL(printPreviewTodo()));
+        this, &TodoView::printPreviewTodo);
     mItemPopupMenu->addSeparator();
     a = mItemPopupMenu->addAction(
         KIconLoader::global()->loadIcon(QStringLiteral("edit-delete"), KIconLoader::NoGroup,
                                         KIconLoader::SizeSmall),
         i18nc("@action:inmenu delete the to-do", "&Delete"),
-        this, SLOT(deleteTodo()));
+        this, &TodoView::deleteTodo);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -361,22 +361,22 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
         KIconLoader::global()->loadIcon(
             QStringLiteral("view-calendar-tasks"), KIconLoader::NoGroup, KIconLoader::SizeSmall),
         i18nc("@action:inmenu create a new to-do", "New &To-do..."),
-        this, SLOT(newTodo()));
+        this, &TodoView::newTodo);
 
     a = mItemPopupMenu->addAction(
         i18nc("@action:inmenu create a new sub-to-do", "New Su&b-to-do..."),
-        this, SLOT(newSubTodo()));
+        this, &TodoView::newSubTodo);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mMakeTodoIndependent = mItemPopupMenu->addAction(
         i18nc("@action:inmenu", "&Make this To-do Independent"),
-        this, SIGNAL(unSubTodoSignal()));
+        this, &TodoView::unSubTodoSignal);
 
     mMakeSubtodosIndependent
         = mItemPopupMenu->addAction(
               i18nc("@action:inmenu", "Make all Sub-to-dos &Independent"),
-              this, SIGNAL(unAllSubTodoSignal()));
+              this, &TodoView::unAllSubTodoSignal);
 
     mItemPopupMenuItemOnlyEntries << mMakeTodoIndependent;
     mItemPopupMenuItemOnlyEntries << mMakeSubtodosIndependent;
@@ -432,7 +432,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenu->addSeparator();
     mItemPopupMenu->addAction(
         i18nc("@action:inmenu delete completed to-dos", "Pur&ge Completed"),
-        this, SIGNAL(purgeCompletedSignal()));
+        this, &TodoView::purgeCompletedSignal);
 
     mPriorityPopupMenu = new QMenu(this);
     mPriority[ mPriorityPopupMenu->addAction(
@@ -673,9 +673,7 @@ void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
 
     KCalCore::Todo::Ptr todo(new KCalCore::Todo);
     todo->setSummary(summaryTrimmed);
-    todo->setOrganizer(
-        Person::Ptr(new Person(CalendarSupport::KCalPrefs::instance()->fullName(),
-                               CalendarSupport::KCalPrefs::instance()->email())));
+    todo->setOrganizer(Person(CalendarSupport::KCalPrefs::instance()->fullName(), CalendarSupport::KCalPrefs::instance()->email()));
 
     todo->setCategories(categories);
 
@@ -945,7 +943,8 @@ void TodoView::onTagsFetched(KJob *job)
     const QStringList checkedCategories = job->property("checkedCategories").toStringList();
     QPointer<QMenu> menu = job->property("menu").value<QPointer<QMenu> >();
     if (menu) {
-        Q_FOREACH (const Akonadi::Tag &tag, fetchJob->tags()) {
+        const auto lst = fetchJob->tags();
+        for (const Akonadi::Tag &tag : lst) {
             const QString name = tag.name();
             QAction *action = menu->addAction(name);
             action->setCheckable(true);
